---
title: Options
---

# Options

<div class="documentation__toc"></div>

## Introduction

Form `options` help configure the behavior in general of the form. Anything from toggling specific UI on or off to adding a simple title and description can be done with the form options.

```php
protected $options = [
    'title'     => 'My awesome form!',
    'form_view' => 'module::my/custom/form'
];
```

You can also set/add options from the API.

```php
$builder->addOption('url', 'http://domain.com/example/api');
```

```twig
{{ form('test', 'example')
    .url('http://domain.com/example/api')
    .render()|raw
}}
```

```twig
{{ form('test', 'example')
    .setOption('url', 'http://domain.com/example/api')
    .render()|raw
}}
```

### Available Options

|Key|Required|Type|Default|Description|
|--- |--- |--- |--- |--- |
|form_view|false|string|streams::form/form|The form view is the primary form layout view.|
|wrapper_view|false|string|streams::blank|The wrapper view is the admin layout wrapper. This is the view you would override if you wanted to include a sidebar with your form for example.|
|permission|false|string|{vendor}.module.{module}::{stream}.write|The permission string required to access the form.|
|url|false|string|The route displaying the form (submits to itself).|The URL for the form submission. This is generally automated but varies depending on how the form is being used.|
